# himena

`himena` is a GUI application framework aiming for highly cooperative GUI development,
mainly focusing on data analysis and visualization.

## Source

[Jump to GitHub repository](https://github.com/hanjinliu/himena).


## Index

- [Tutorial](tutorial.md)
- [Developper's Guide](dev/index.md)
